@@ -7,7 +7,7 @@ from dagster.core.definitions.events import AssetKey
 from dagster.core.events.log import EventLogEntry
 from dagster.core.host_representation import ExternalRepository
 from dagster.core.scheduler.instigation import InstigatorType
-from dagster.core.storage.pipeline_run import JobBucket, PipelineRunsFilter, RunRecord, TagBucket
+from dagster.core.storage.pipeline_run import JobBucket, RunRecord, RunsFilter, TagBucket
 from dagster.core.storage.tags import SCHEDULE_NAME_TAG, SENSOR_NAME_TAG
 
 
@@ -67,7 +67,7 @@ class RepositoryScopedBatchLoader:
                     records.extend(
                         list(
                             self._instance.get_run_records(
-                                filters=PipelineRunsFilter(pipeline_name=job_name), limit=limit
+                                filters=RunsFilter(pipeline_name=job_name), limit=limit
                             )
                         )
                     )
@@ -92,7 +92,7 @@ class RepositoryScopedBatchLoader:
                     records.extend(
                         list(
                             self._instance.get_run_records(
-                                filters=PipelineRunsFilter(tags={SCHEDULE_NAME_TAG: schedule_name}),
+                                filters=RunsFilter(tags={SCHEDULE_NAME_TAG: schedule_name}),
                                 limit=limit,
                             )
                         )
@@ -116,7 +116,7 @@ class RepositoryScopedBatchLoader:
                     records.extend(
                         list(
                             self._instance.get_run_records(
-                                filters=PipelineRunsFilter(tags={SENSOR_NAME_TAG: sensor_name}),
+                                filters=RunsFilter(tags={SENSOR_NAME_TAG: sensor_name}),
                                 limit=limit,
                             )
                         )
@@ -203,7 +203,7 @@ class BatchRunLoader:
         return self._records.get(run_id)
 
     def _fetch(self):
-        records = self._instance.get_run_records(PipelineRunsFilter(run_ids=list(self._run_ids)))
+        records = self._instance.get_run_records(RunsFilter(run_ids=list(self._run_ids)))
         for record in records:
             self._records[record.pipeline_run.run_id] = record
 
