@@ -1,11 +1,14 @@
+import graphene
+
 from dagster import check
 from dagster.config.config_type import ConfigTypeKind
 from dagster.config.snap import get_recursive_type_keys
 from dagster.core.snap import ConfigFieldSnap, ConfigSchemaSnapshot, ConfigTypeSnap
-from dagster_graphql import dauphin
+
+from .util import non_null_list
 
 
-def to_dauphin_config_type(config_schema_snapshot, config_type_key):
+def to_config_type(config_schema_snapshot, config_type_key):
     check.inst_param(config_schema_snapshot, "config_schema_snapshot", ConfigSchemaSnapshot)
     check.str_param(config_type_key, "config_type_key")
 
@@ -13,17 +16,19 @@ def to_dauphin_config_type(config_schema_snapshot, config_type_key):
     kind = config_type_snap.kind
 
     if kind == ConfigTypeKind.ENUM:
-        return DauphinEnumConfigType(config_schema_snapshot, config_type_snap)
+        return GrapheneEnumConfigType(config_schema_snapshot, config_type_snap)
     elif ConfigTypeKind.has_fields(kind):
-        return DauphinCompositeConfigType(config_schema_snapshot, config_type_snap)
+        return GrapheneCompositeConfigType(config_schema_snapshot, config_type_snap)
     elif kind == ConfigTypeKind.ARRAY:
-        return DauphinArrayConfigType(config_schema_snapshot, config_type_snap)
+        return GrapheneArrayConfigType(config_schema_snapshot, config_type_snap)
+    elif kind == ConfigTypeKind.MAP:
+        return GrapheneMapConfigType(config_schema_snapshot, config_type_snap)
     elif kind == ConfigTypeKind.NONEABLE:
-        return DauphinNullableConfigType(config_schema_snapshot, config_type_snap)
+        return GrapheneNullableConfigType(config_schema_snapshot, config_type_snap)
     elif kind == ConfigTypeKind.ANY or kind == ConfigTypeKind.SCALAR:
-        return DauphinRegularConfigType(config_schema_snapshot, config_type_snap)
+        return GrapheneRegularConfigType(config_schema_snapshot, config_type_snap)
     elif kind == ConfigTypeKind.SCALAR_UNION:
-        return DauphinScalarUnionConfigType(config_schema_snapshot, config_type_snap)
+        return GrapheneScalarUnionConfigType(config_schema_snapshot, config_type_snap)
     else:
         check.failed("Should never reach")
 
@@ -37,15 +42,12 @@ def _ctor_kwargs_for_snap(config_type_snap):
     )
 
 
-class DauphinConfigType(dauphin.Interface):
-    class Meta:
-        name = "ConfigType"
+class GrapheneConfigType(graphene.Interface):
+    key = graphene.NonNull(graphene.String)
+    description = graphene.String()
 
-    key = dauphin.NonNull(dauphin.String)
-    description = dauphin.String()
-
-    recursive_config_types = dauphin.Field(
-        dauphin.non_null_list("ConfigType"),
+    recursive_config_types = graphene.Field(
+        non_null_list(lambda: GrapheneConfigType),
         description="""
 This is an odd and problematic field. It recursively goes down to
 get all the types contained within a type. The case where it is horrible
@@ -63,15 +65,18 @@ want to be able to render them, but without fetching the entire schema.
 We use this capability when rendering the sidebar.
     """,
     )
-    type_param_keys = dauphin.Field(
-        dauphin.non_null_list(dauphin.String),
+    type_param_keys = graphene.Field(
+        non_null_list(graphene.String),
         description="""
 This returns the keys for type parameters of any closed generic type,
 (e.g. List, Optional). This should be used for reconstructing and
 navigating the full schema client-side and not innerTypes.
     """,
     )
-    is_selector = dauphin.NonNull(dauphin.Boolean)
+    is_selector = graphene.NonNull(graphene.Boolean)
+
+    class Meta:
+        name = "ConfigType"
 
 
 class ConfigTypeMixin:
@@ -82,57 +87,83 @@ class ConfigTypeMixin:
         self._config_schema_snapshot = check.inst_param(
             config_schema_snapshot, "config_schema_snapshot", ConfigSchemaSnapshot
         )
-        super(ConfigTypeMixin, self).__init__(**_ctor_kwargs_for_snap(config_type_snap))
+        super().__init__(**_ctor_kwargs_for_snap(config_type_snap))
 
     def resolve_recursive_config_types(self, _graphene_info):
         return list(
             map(
-                lambda key: to_dauphin_config_type(self._config_schema_snapshot, key),
+                lambda key: to_config_type(self._config_schema_snapshot, key),
                 get_recursive_type_keys(self._config_type_snap, self._config_schema_snapshot),
             )
         )
 
 
-class DauphinRegularConfigType(ConfigTypeMixin, dauphin.ObjectType):
+class GrapheneRegularConfigType(ConfigTypeMixin, graphene.ObjectType):
     class Meta:
-        name = "RegularConfigType"
-        interfaces = [DauphinConfigType]
+        interfaces = (GrapheneConfigType,)
         description = "Regular is an odd name in this context. It really means Scalar or Any."
+        name = "RegularConfigType"
 
-    given_name = dauphin.NonNull(dauphin.String)
+    given_name = graphene.NonNull(graphene.String)
 
     def resolve_given_name(self, _):
         return self._config_type_snap.given_name
 
 
-class DauphinWrappingConfigType(dauphin.Interface):
+class GrapheneMapConfigType(ConfigTypeMixin, graphene.ObjectType):
+
+    key_type = graphene.Field(graphene.NonNull(GrapheneConfigType))
+    value_type = graphene.Field(graphene.NonNull(GrapheneConfigType))
+    key_label_name = graphene.Field(graphene.String)
+
+    class Meta:
+        interfaces = (GrapheneConfigType,)
+        name = "MapConfigType"
+
+    def resolve_key_type(self, _graphene_info):
+        return to_config_type(
+            self._config_schema_snapshot,
+            self._config_type_snap.key_type_key,
+        )
+
+    def resolve_value_type(self, _graphene_info):
+        return to_config_type(
+            self._config_schema_snapshot,
+            self._config_type_snap.inner_type_key,
+        )
+
+    def resolve_key_label_name(self, _graphene_info):
+        return self._config_type_snap.given_name
+
+
+class GrapheneWrappingConfigType(graphene.Interface):
+    of_type = graphene.Field(graphene.NonNull(GrapheneConfigType))
+
     class Meta:
         name = "WrappingConfigType"
 
-    of_type = dauphin.Field(dauphin.NonNull(DauphinConfigType))
 
-
-class DauphinArrayConfigType(ConfigTypeMixin, dauphin.ObjectType):
+class GrapheneArrayConfigType(ConfigTypeMixin, graphene.ObjectType):
     class Meta:
+        interfaces = (GrapheneConfigType, GrapheneWrappingConfigType)
         name = "ArrayConfigType"
-        interfaces = [DauphinConfigType, DauphinWrappingConfigType]
 
     def resolve_of_type(self, _graphene_info):
-        return to_dauphin_config_type(
-            self._config_schema_snapshot, self._config_type_snap.inner_type_key,
+        return to_config_type(
+            self._config_schema_snapshot,
+            self._config_type_snap.inner_type_key,
         )
 
 
-class DauphinScalarUnionConfigType(ConfigTypeMixin, dauphin.ObjectType):
+class GrapheneScalarUnionConfigType(ConfigTypeMixin, graphene.ObjectType):
+    scalar_type = graphene.NonNull(GrapheneConfigType)
+    non_scalar_type = graphene.NonNull(GrapheneConfigType)
+    scalar_type_key = graphene.NonNull(graphene.String)
+    non_scalar_type_key = graphene.NonNull(graphene.String)
+
     class Meta:
+        interfaces = (GrapheneConfigType,)
         name = "ScalarUnionConfigType"
-        interfaces = [DauphinConfigType]
-
-    scalar_type = dauphin.NonNull(DauphinConfigType)
-    non_scalar_type = dauphin.NonNull(DauphinConfigType)
-
-    scalar_type_key = dauphin.NonNull(dauphin.String)
-    non_scalar_type_key = dauphin.NonNull(dauphin.String)
 
     def get_scalar_type_key(self):
         return self._config_type_snap.scalar_type_key
@@ -147,34 +178,40 @@ class DauphinScalarUnionConfigType(ConfigTypeMixin, dauphin.ObjectType):
         return self.get_non_scalar_type_key()
 
     def resolve_scalar_type(self, _):
-        return to_dauphin_config_type(self._config_schema_snapshot, self.get_scalar_type_key())
+        return to_config_type(self._config_schema_snapshot, self.get_scalar_type_key())
 
     def resolve_non_scalar_type(self, _):
-        return to_dauphin_config_type(self._config_schema_snapshot, self.get_non_scalar_type_key())
+        return to_config_type(self._config_schema_snapshot, self.get_non_scalar_type_key())
 
 
-class DauphinNullableConfigType(ConfigTypeMixin, dauphin.ObjectType):
+class GrapheneNullableConfigType(ConfigTypeMixin, graphene.ObjectType):
     class Meta:
+        interfaces = (GrapheneConfigType, GrapheneWrappingConfigType)
         name = "NullableConfigType"
-        interfaces = [DauphinConfigType, DauphinWrappingConfigType]
 
     def resolve_of_type(self, _graphene_info):
-        return to_dauphin_config_type(
-            self._config_schema_snapshot, self._config_type_snap.inner_type_key
-        )
+        return to_config_type(self._config_schema_snapshot, self._config_type_snap.inner_type_key)
 
 
-class DauphinEnumConfigType(ConfigTypeMixin, dauphin.ObjectType):
+class GrapheneEnumConfigValue(graphene.ObjectType):
+    value = graphene.NonNull(graphene.String)
+    description = graphene.String()
+
     class Meta:
-        name = "EnumConfigType"
-        interfaces = [DauphinConfigType]
+        name = "EnumConfigValue"
 
-    values = dauphin.non_null_list("EnumConfigValue")
-    given_name = dauphin.NonNull(dauphin.String)
+
+class GrapheneEnumConfigType(ConfigTypeMixin, graphene.ObjectType):
+    class Meta:
+        interfaces = (GrapheneConfigType,)
+        name = "EnumConfigType"
+
+    values = non_null_list(GrapheneEnumConfigValue)
+    given_name = graphene.NonNull(graphene.String)
 
     def resolve_values(self, _graphene_info):
         return [
-            DauphinEnumConfigValue(value=ev.value, description=ev.description)
+            GrapheneEnumConfigValue(value=ev.value, description=ev.description)
             for ev in self._config_type_snap.enum_values
         ]
 
@@ -182,43 +219,16 @@ class DauphinEnumConfigType(ConfigTypeMixin, dauphin.ObjectType):
         return self._config_type_snap.given_name
 
 
-class DauphinEnumConfigValue(dauphin.ObjectType):
-    class Meta:
-        name = "EnumConfigValue"
+class GrapheneConfigTypeField(graphene.ObjectType):
+    name = graphene.NonNull(graphene.String)
+    description = graphene.String()
+    config_type = graphene.NonNull(GrapheneConfigType)
+    config_type_key = graphene.NonNull(graphene.String)
+    is_required = graphene.NonNull(graphene.Boolean)
 
-    value = dauphin.NonNull(dauphin.String)
-    description = dauphin.String()
-
-
-class DauphinCompositeConfigType(ConfigTypeMixin, dauphin.ObjectType):
-    class Meta:
-        name = "CompositeConfigType"
-        interfaces = [DauphinConfigType]
-
-    fields = dauphin.non_null_list("ConfigTypeField")
-
-    def resolve_fields(self, _graphene_info):
-        return sorted(
-            [
-                DauphinConfigTypeField(
-                    config_schema_snapshot=self._config_schema_snapshot, field_snap=field_snap,
-                )
-                for field_snap in self._config_type_snap.fields
-            ],
-            key=lambda field: field.name,
-        )
-
-
-class DauphinConfigTypeField(dauphin.ObjectType):
     class Meta:
         name = "ConfigTypeField"
 
-    name = dauphin.NonNull(dauphin.String)
-    description = dauphin.String()
-    config_type = dauphin.NonNull("ConfigType")
-    config_type_key = dauphin.NonNull(dauphin.String)
-    is_required = dauphin.NonNull(dauphin.Boolean)
-
     def resolve_config_type_key(self, _):
         return self._field_snap.type_key
 
@@ -227,11 +237,46 @@ class DauphinConfigTypeField(dauphin.ObjectType):
             config_schema_snapshot, "config_schema_snapshot", ConfigSchemaSnapshot
         )
         self._field_snap = check.inst_param(field_snap, "field_snap", ConfigFieldSnap)
-        super(DauphinConfigTypeField, self).__init__(
+        super().__init__(
             name=field_snap.name,
             description=field_snap.description,
             is_required=field_snap.is_required,
         )
 
     def resolve_config_type(self, _graphene_info):
-        return to_dauphin_config_type(self._config_schema_snapshot, self._field_snap.type_key)
+        return to_config_type(self._config_schema_snapshot, self._field_snap.type_key)
+
+
+class GrapheneCompositeConfigType(ConfigTypeMixin, graphene.ObjectType):
+    fields = non_null_list(GrapheneConfigTypeField)
+
+    class Meta:
+        interfaces = (GrapheneConfigType,)
+        name = "CompositeConfigType"
+
+    def resolve_fields(self, _graphene_info):
+        return sorted(
+            [
+                GrapheneConfigTypeField(
+                    config_schema_snapshot=self._config_schema_snapshot,
+                    field_snap=field_snap,
+                )
+                for field_snap in self._config_type_snap.fields
+            ],
+            key=lambda field: field.name,
+        )
+
+
+types = [
+    GrapheneArrayConfigType,
+    GrapheneCompositeConfigType,
+    GrapheneConfigType,
+    GrapheneConfigTypeField,
+    GrapheneEnumConfigType,
+    GrapheneEnumConfigValue,
+    GrapheneNullableConfigType,
+    GrapheneRegularConfigType,
+    GrapheneScalarUnionConfigType,
+    GrapheneWrappingConfigType,
+    GrapheneMapConfigType,
+]
