@@ -326,6 +326,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_in_memory_instance_lazy_r
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -429,6 +449,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_in_memory_instance_manage
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -532,6 +572,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_in_memory_instance_multi_
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -635,6 +695,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_postgres_instance_lazy_re
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -738,6 +818,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_postgres_instance_managed
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -841,6 +941,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_postgres_instance_multi_l
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -944,6 +1064,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_sqlite_instance_deployed_
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -1047,6 +1187,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_sqlite_instance_lazy_repo
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -1150,6 +1310,26 @@ snapshots['TestSensors.test_get_sensors[non_launchable_sqlite_instance_managed_g
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
 
@@ -1253,5 +1433,25 @@ snapshots['TestSensors.test_get_sensors[non_launchable_sqlite_instance_multi_loc
                 'solidSelection': None
             }
         ]
+    },
+    {
+        'description': None,
+        'minIntervalSeconds': 30,
+        'name': 'running_in_code_sensor',
+        'sensorState': {
+            'runs': [
+            ],
+            'runsCount': 0,
+            'status': 'RUNNING',
+            'ticks': [
+            ]
+        },
+        'targets': [
+            {
+                'mode': 'default',
+                'pipelineName': 'no_config_pipeline',
+                'solidSelection': None
+            }
+        ]
     }
 ]
