@@ -1,7 +1,10 @@
+import json
+
+from dagster_graphql.test.utils import execute_dagster_graphql, infer_pipeline_selector
+
 from dagster import check
 from dagster.config.config_type import ALL_CONFIG_BUILTINS
 from dagster.utils import file_relative_path
-from dagster_graphql.test.utils import execute_dagster_graphql, infer_pipeline_selector
 
 from .graphql_context_test_suite import NonLaunchableGraphQLContextTestMatrix
 from .setup import csv_hello_world_solids_config
@@ -54,6 +57,12 @@ query PipelineQuery(
                         ... on EvaluationStackListItemEntry {
                             listIndex
                         }
+                        ... on EvaluationStackMapKeyEntry {
+                            mapKey
+                        }
+                        ... on EvaluationStackMapValueEntry {
+                            mapKey
+                        }
                     }
                 }
             }
@@ -133,6 +142,19 @@ class TestConfigTypes(NonLaunchableGraphQLContextTestMatrix):
         assert result.data["isPipelineConfigValid"]["__typename"] == "PipelineConfigValidationValid"
         assert result.data["isPipelineConfigValid"]["pipelineName"] == "csv_hello_world"
 
+    def test_basic_valid_config_serialized_config(self, graphql_context):
+        result = execute_config_graphql(
+            graphql_context,
+            pipeline_name="csv_hello_world",
+            run_config=json.dumps(csv_hello_world_solids_config()),
+            mode="default",
+        )
+
+        assert not result.errors
+        assert result.data
+        assert result.data["isPipelineConfigValid"]["__typename"] == "PipelineConfigValidationValid"
+        assert result.data["isPipelineConfigValid"]["pipelineName"] == "csv_hello_world"
+
     def test_root_field_not_defined(self, graphql_context):
         result = execute_config_graphql(
             graphql_context,
@@ -512,6 +534,113 @@ class TestConfigTypes(NonLaunchableGraphQLContextTestMatrix):
         assert last_entry["__typename"] == "EvaluationStackListItemEntry"
         assert last_entry["listIndex"] == 1
 
+    def test_config_map(self, graphql_context):
+        # Check validity
+        result = execute_config_graphql(
+            graphql_context,
+            pipeline_name="config_with_map",
+            run_config={
+                "solids": {"a_solid_with_map_config": {"config": {"field_one": {"test": 5}}}}
+            },
+            mode="default",
+        )
+
+        assert not result.errors
+        assert result.data
+        valid_data = result.data["isPipelineConfigValid"]
+        assert valid_data["__typename"] == "PipelineConfigValidationValid"
+        assert valid_data["pipelineName"] == "config_with_map"
+
+        # Sanity check GraphQL result for types
+        selector = infer_pipeline_selector(graphql_context, "config_with_map")
+        result = execute_dagster_graphql(
+            graphql_context,
+            ALL_CONFIG_TYPES_QUERY,
+            {"selector": selector, "mode": "default"},
+        )
+        config_types_data = result.data["runConfigSchemaOrError"]["allConfigTypes"]
+        # Ensure the first config type, Map(str, int, name="username") is in the result
+        assert any(
+            config_type_data.get("keyLabelName") == "username"
+            and config_type_data.get("keyType", {}).get("key", "") == "String"
+            and config_type_data.get("valueType", {}).get("key", "") == "Int"
+            for config_type_data in config_types_data
+        )
+
+    def test_config_map_invalid(self, graphql_context):
+        result = execute_config_graphql(
+            graphql_context,
+            pipeline_name="config_with_map",
+            run_config={
+                "solids": {"a_solid_with_map_config": {"config": {"field_one": "not_a_map"}}}
+            },
+            mode="default",
+        )
+
+        assert not result.errors
+        assert result.data
+        valid_data = result.data["isPipelineConfigValid"]
+        assert valid_data["__typename"] == "RunConfigValidationInvalid"
+        assert valid_data["pipelineName"] == "config_with_map"
+        assert len(valid_data["errors"]) == 1
+        assert ["solids", "a_solid_with_map_config", "config", "field_one"] == field_stack(
+            valid_data["errors"][0]
+        )
+
+    def test_config_map_key_invalid(self, graphql_context):
+        result = execute_config_graphql(
+            graphql_context,
+            pipeline_name="config_with_map",
+            run_config={"solids": {"a_solid_with_map_config": {"config": {"field_one": {5: 5}}}}},
+            mode="default",
+        )
+
+        assert not result.errors
+        assert result.data
+        valid_data = result.data["isPipelineConfigValid"]
+        assert valid_data["__typename"] == "RunConfigValidationInvalid"
+        assert valid_data["pipelineName"] == "config_with_map"
+        assert len(valid_data["errors"]) == 1
+        entries = valid_data["errors"][0]["stack"]["entries"]
+        assert len(entries) == 5
+        assert ["solids", "a_solid_with_map_config", "config", "field_one"] == field_stack(
+            valid_data["errors"][0]
+        )
+
+        last_entry = entries[4]
+        assert last_entry["__typename"] == "EvaluationStackMapKeyEntry"
+        assert last_entry["mapKey"] == 5
+
+    def test_config_map_value_invalid(self, graphql_context):
+        result = execute_config_graphql(
+            graphql_context,
+            pipeline_name="config_with_map",
+            run_config={
+                "solids": {
+                    "a_solid_with_map_config": {
+                        "config": {"field_one": {"test": "not_a_valid_int_value"}}
+                    }
+                }
+            },
+            mode="default",
+        )
+
+        assert not result.errors
+        assert result.data
+        valid_data = result.data["isPipelineConfigValid"]
+        assert valid_data["__typename"] == "RunConfigValidationInvalid"
+        assert valid_data["pipelineName"] == "config_with_map"
+        assert len(valid_data["errors"]) == 1
+        entries = valid_data["errors"][0]["stack"]["entries"]
+        assert len(entries) == 5
+        assert ["solids", "a_solid_with_map_config", "config", "field_one"] == field_stack(
+            valid_data["errors"][0]
+        )
+
+        last_entry = entries[4]
+        assert last_entry["__typename"] == "EvaluationStackMapValueEntry"
+        assert last_entry["mapKey"] == "test"
+
     def test_smoke_test_config_type_system(self, graphql_context):
         selector = infer_pipeline_selector(graphql_context, "more_complicated_nested_config")
         result = execute_dagster_graphql(
@@ -592,6 +721,11 @@ fragment configTypeFragment on ConfigType {
   ... on WrappingConfigType {
     ofType { key }
   }
+  ... on MapConfigType {
+    keyType { key }
+    valueType { key }
+    keyLabelName
+  }
   ... on ScalarUnionConfigType {
     scalarType { key }
     nonScalarType { key }
