@@ -1,8 +1,9 @@
 import json
 
-from dagster.utils import file_relative_path
 from dagster_graphql.test.utils import infer_pipeline_selector
 
+from dagster.utils import file_relative_path
+
 from .graphql_context_test_suite import ExecutingGraphQLContextTestMatrix
 from .utils import sync_execute_get_events
 
@@ -10,9 +11,9 @@ from .utils import sync_execute_get_events
 def get_expectation_results(logs, solid_name):
     def _f():
         for log in logs:
-            if log["__typename"] == "StepExpectationResultEvent" and log[
-                "stepKey"
-            ] == "{}.compute".format(solid_name):
+            if log["__typename"] == "StepExpectationResultEvent" and log["stepKey"] == "{}".format(
+                solid_name
+            ):
                 yield log
 
     return list(_f())
