@@ -1,3 +1,4 @@
+import os
 from time import sleep
 
 from dagster_graphql.client.query import (
@@ -11,24 +12,17 @@ from dagster_graphql.test.utils import (
     infer_pipeline_selector,
 )
 
-from dagster.core.execution.plan.objects import StepOutputHandle
-from dagster.core.storage.intermediate_storage import build_fs_intermediate_storage
+from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.core.storage.tags import RESUME_RETRY_TAG
+from dagster.core.test_utils import poll_for_finished_run
 from dagster.core.utils import make_new_run_id
 
 from .graphql_context_test_suite import (
     ExecutingGraphQLContextTestMatrix,
     GraphQLContextVariant,
-    OutOfProcessExecutingGraphQLContextTestMatrix,
     make_graphql_context_test_suite,
 )
-from .setup import (
-    PoorMansDataFrame,
-    csv_hello_world_solids_config,
-    csv_hello_world_solids_config_fs_storage,
-    get_retry_multi_execution_params,
-    retry_config,
-)
+from .setup import csv_hello_world_solids_config, get_retry_multi_execution_params, retry_config
 from .utils import (
     get_all_logs_for_finished_run_via_subscription,
     step_did_fail,
@@ -86,11 +80,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             "pipelineRunLogs"
         ]["messages"]
 
-        assert step_did_succeed(logs, "spawn.compute")
-        assert step_did_fail(logs, "fail.compute")
-        assert step_did_not_run(logs, "fail_2.compute")
-        assert step_did_not_run(logs, "fail_3.compute")
-        assert step_did_not_run(logs, "reset.compute")
+        assert step_did_succeed(logs, "spawn")
+        assert step_did_fail(logs, "fail")
+        assert step_did_not_run(logs, "fail_2")
+        assert step_did_not_run(logs, "fail_3")
+        assert step_did_not_run(logs, "reset")
+        assert step_did_not_run(logs, "collect")
 
         retry_one = execute_dagster_graphql_and_finish_runs(
             graphql_context,
@@ -113,11 +108,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(graphql_context, run_id)[
             "pipelineRunLogs"
         ]["messages"]
-        assert step_did_not_run(logs, "spawn.compute")
-        assert step_did_succeed(logs, "fail.compute")
-        assert step_did_fail(logs, "fail_2.compute")
-        assert step_did_not_run(logs, "fail_3.compute")
-        assert step_did_not_run(logs, "reset.compute")
+        assert step_did_not_run(logs, "spawn")
+        assert step_did_succeed(logs, "fail")
+        assert step_did_fail(logs, "fail_2")
+        assert step_did_not_run(logs, "fail_3")
+        assert step_did_not_run(logs, "reset")
+        assert step_did_not_run(logs, "collect")
 
         retry_two = execute_dagster_graphql_and_finish_runs(
             graphql_context,
@@ -141,11 +137,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             "pipelineRunLogs"
         ]["messages"]
 
-        assert step_did_not_run(logs, "spawn.compute")
-        assert step_did_not_run(logs, "fail.compute")
-        assert step_did_succeed(logs, "fail_2.compute")
-        assert step_did_fail(logs, "fail_3.compute")
-        assert step_did_not_run(logs, "reset.compute")
+        assert step_did_not_run(logs, "spawn")
+        assert step_did_not_run(logs, "fail")
+        assert step_did_succeed(logs, "fail_2")
+        assert step_did_fail(logs, "fail_3")
+        assert step_did_not_run(logs, "reset")
+        assert step_did_not_run(logs, "collect")
 
         retry_three = execute_dagster_graphql_and_finish_runs(
             graphql_context,
@@ -169,11 +166,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             "pipelineRunLogs"
         ]["messages"]
 
-        assert step_did_not_run(logs, "spawn.compute")
-        assert step_did_not_run(logs, "fail.compute")
-        assert step_did_not_run(logs, "fail_2.compute")
-        assert step_did_succeed(logs, "fail_3.compute")
-        assert step_did_succeed(logs, "reset.compute")
+        assert step_did_not_run(logs, "spawn")
+        assert step_did_not_run(logs, "fail")
+        assert step_did_not_run(logs, "fail_2")
+        assert step_did_succeed(logs, "fail_3")
+        assert step_did_succeed(logs, "reset")
+        assert step_did_succeed(logs, "collect")
 
     def test_retry_resource_pipeline(self, graphql_context):
         context = graphql_context
@@ -185,7 +183,6 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
                 "executionParams": {
                     "mode": "default",
                     "selector": selector,
-                    "runConfigData": {"storage": {"filesystem": {}}},
                 }
             },
         )
@@ -194,8 +191,8 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(context, run_id)["pipelineRunLogs"][
             "messages"
         ]
-        assert step_did_succeed(logs, "start.compute")
-        assert step_did_fail(logs, "will_fail.compute")
+        assert step_did_succeed(logs, "start")
+        assert step_did_fail(logs, "will_fail")
 
         retry_one = execute_dagster_graphql_and_finish_runs(
             context,
@@ -204,7 +201,6 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
                 "executionParams": {
                     "mode": "default",
                     "selector": selector,
-                    "runConfigData": {"storage": {"filesystem": {}}},
                     "executionMetadata": {
                         "rootRunId": run_id,
                         "parentRunId": run_id,
@@ -217,8 +213,8 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(context, run_id)["pipelineRunLogs"][
             "messages"
         ]
-        assert step_did_not_run(logs, "start.compute")
-        assert step_did_fail(logs, "will_fail.compute")
+        assert step_did_not_run(logs, "start")
+        assert step_did_fail(logs, "will_fail")
 
     def test_retry_multi_output(self, graphql_context):
         context = graphql_context
@@ -234,12 +230,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(context, run_id)["pipelineRunLogs"][
             "messages"
         ]
-        assert step_did_succeed(logs, "multi.compute")
-        assert step_did_skip(logs, "child_multi_skip.compute")
-        assert step_did_fail(logs, "can_fail.compute")
-        assert step_did_not_run(logs, "child_fail.compute")
-        assert step_did_not_run(logs, "child_skip.compute")
-        assert step_did_not_run(logs, "grandchild_fail.compute")
+        assert step_did_succeed(logs, "multi")
+        assert step_did_skip(logs, "child_multi_skip")
+        assert step_did_fail(logs, "can_fail")
+        assert step_did_not_run(logs, "child_fail")
+        assert step_did_not_run(logs, "child_skip")
+        assert step_did_not_run(logs, "grandchild_fail")
 
         retry_one = execute_dagster_graphql_and_finish_runs(
             context,
@@ -255,12 +251,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(context, run_id)["pipelineRunLogs"][
             "messages"
         ]
-        assert step_did_not_run(logs, "multi.compute")
-        assert step_did_not_run(logs, "child_multi_skip.compute")
-        assert step_did_fail(logs, "can_fail.compute")
-        assert step_did_not_run(logs, "child_fail.compute")
-        assert step_did_not_run(logs, "child_skip.compute")
-        assert step_did_not_run(logs, "grandchild_fail.compute")
+        assert step_did_not_run(logs, "multi")
+        assert step_did_not_run(logs, "child_multi_skip")
+        assert step_did_fail(logs, "can_fail")
+        assert step_did_not_run(logs, "child_fail")
+        assert step_did_not_run(logs, "child_skip")
+        assert step_did_not_run(logs, "grandchild_fail")
 
         retry_two = execute_dagster_graphql_and_finish_runs(
             context,
@@ -276,12 +272,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(context, run_id)["pipelineRunLogs"][
             "messages"
         ]
-        assert step_did_not_run(logs, "multi.compute")
-        assert step_did_not_run(logs, "child_multi_skip.compute")
-        assert step_did_succeed(logs, "can_fail.compute")
-        assert step_did_succeed(logs, "child_fail.compute")
-        assert step_did_skip(logs, "child_skip.compute")
-        assert step_did_succeed(logs, "grandchild_fail.compute")
+        assert step_did_not_run(logs, "multi")
+        assert step_did_not_run(logs, "child_multi_skip")
+        assert step_did_succeed(logs, "can_fail")
+        assert step_did_succeed(logs, "child_fail")
+        assert step_did_skip(logs, "child_skip")
+        assert step_did_succeed(logs, "grandchild_fail")
 
     def test_successful_pipeline_reexecution(self, graphql_context):
         selector = infer_pipeline_selector(graphql_context, "csv_hello_world")
@@ -292,37 +288,22 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": csv_hello_world_solids_config_fs_storage(),
+                    "runConfigData": csv_hello_world_solids_config(),
                     "executionMetadata": {"runId": run_id},
                     "mode": "default",
                 }
             },
         )
 
-        assert (
-            result_one.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-        )
-
-        expected_value_repr = (
-            """[OrderedDict([('num1', '1'), ('num2', '2'), ('sum', 3), """
-            """('sum_sq', 9)]), OrderedDict([('num1', '3'), ('num2', '4'), ('sum', 7), """
-            """('sum_sq', 49)])]"""
-        )
+        assert result_one.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
 
         instance = graphql_context.instance
 
-        intermediate_storage = build_fs_intermediate_storage(
-            instance.intermediates_directory, run_id
+        assert os.path.exists(
+            os.path.join(instance.storage_directory(), run_id, "sum_solid", "result")
         )
-        assert intermediate_storage.has_intermediate(None, StepOutputHandle("sum_solid.compute"))
-        assert intermediate_storage.has_intermediate(None, StepOutputHandle("sum_sq_solid.compute"))
-        assert (
-            str(
-                intermediate_storage.get_intermediate(
-                    None, PoorMansDataFrame, StepOutputHandle("sum_sq_solid.compute")
-                ).obj
-            )
-            == expected_value_repr
+        assert os.path.exists(
+            os.path.join(instance.storage_directory(), run_id, "sum_sq_solid", "result")
         )
 
         # retry
@@ -334,8 +315,8 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": csv_hello_world_solids_config_fs_storage(),
-                    "stepKeys": ["sum_sq_solid.compute"],
+                    "runConfigData": csv_hello_world_solids_config(),
+                    "stepKeys": ["sum_sq_solid"],
                     "executionMetadata": {
                         "runId": new_run_id,
                         "rootRunId": run_id,
@@ -348,34 +329,32 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         )
 
         query_result = result_two.data["launchPipelineReexecution"]
-        assert query_result["__typename"] == "LaunchPipelineRunSuccess"
+        assert query_result["__typename"] == "LaunchRunSuccess"
 
         result = get_all_logs_for_finished_run_via_subscription(graphql_context, new_run_id)
         logs = result["pipelineRunLogs"]["messages"]
 
         assert isinstance(logs, list)
-        assert has_event_of_type(logs, "PipelineStartEvent")
-        assert has_event_of_type(logs, "PipelineSuccessEvent")
-        assert not has_event_of_type(logs, "PipelineFailureEvent")
+        assert has_event_of_type(logs, "RunStartEvent")
+        assert has_event_of_type(logs, "RunSuccessEvent")
+        assert not has_event_of_type(logs, "RunFailureEvent")
 
-        assert not get_step_output_event(logs, "sum_solid.compute")
-        assert get_step_output_event(logs, "sum_sq_solid.compute")
+        assert not get_step_output_event(logs, "sum_solid")
+        assert get_step_output_event(logs, "sum_sq_solid")
 
-        intermediate_storage = build_fs_intermediate_storage(
-            instance.intermediates_directory, new_run_id
-        )
-        assert not intermediate_storage.has_intermediate(
-            None, StepOutputHandle("sum_solid.inputs.num.read", "input_thunk_output")
-        )
-        assert intermediate_storage.has_intermediate(None, StepOutputHandle("sum_solid.compute"))
-        assert intermediate_storage.has_intermediate(None, StepOutputHandle("sum_sq_solid.compute"))
-        assert (
-            str(
-                intermediate_storage.get_intermediate(
-                    None, PoorMansDataFrame, StepOutputHandle("sum_sq_solid.compute")
-                ).obj
+        assert not os.path.exists(
+            os.path.join(
+                instance.storage_directory(),
+                new_run_id,
+                "sum_solid.inputs.num.read",
+                "input_thunk_output",
             )
-            == expected_value_repr
+        )
+        assert not os.path.exists(
+            os.path.join(instance.storage_directory(), new_run_id, "sum_solid", "result")
+        )
+        assert os.path.exists(
+            os.path.join(instance.storage_directory(), new_run_id, "sum_sq_solid", "result")
         )
 
     def test_pipeline_reexecution_info_query(self, graphql_context, snapshot):
@@ -389,7 +368,7 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": csv_hello_world_solids_config_fs_storage(),
+                    "runConfigData": csv_hello_world_solids_config(),
                     "executionMetadata": {"runId": run_id},
                     "mode": "default",
                 }
@@ -404,8 +383,8 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": csv_hello_world_solids_config_fs_storage(),
-                    "stepKeys": ["sum_sq_solid.compute"],
+                    "runConfigData": csv_hello_world_solids_config(),
+                    "stepKeys": ["sum_sq_solid"],
                     "executionMetadata": {
                         "runId": new_run_id,
                         "rootRunId": run_id,
@@ -421,14 +400,14 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
             context, PIPELINE_REEXECUTION_INFO_QUERY, variables={"runId": run_id}
         )
         query_result_one = result_one.data["pipelineRunOrError"]
-        assert query_result_one["__typename"] == "PipelineRun"
+        assert query_result_one["__typename"] == "Run"
         assert query_result_one["stepKeysToExecute"] is None
 
         result_two = execute_dagster_graphql_and_finish_runs(
             context, PIPELINE_REEXECUTION_INFO_QUERY, variables={"runId": new_run_id}
         )
         query_result_two = result_two.data["pipelineRunOrError"]
-        assert query_result_two["__typename"] == "PipelineRun"
+        assert query_result_two["__typename"] == "Run"
         stepKeysToExecute = query_result_two["stepKeysToExecute"]
         assert stepKeysToExecute is not None
         snapshot.assert_match(stepKeysToExecute)
@@ -472,11 +451,12 @@ class TestRetryExecution(ExecutingGraphQLContextTestMatrix):
         )
 
         query_result = result_two.data["launchPipelineReexecution"]
-        assert query_result["__typename"] == "InvalidStepError"
-        assert query_result["invalidStepKey"] == "nope"
+        assert query_result["__typename"] == "PythonError"
+        assert query_result["className"] == "DagsterExecutionStepNotFoundError"
+        assert "Can not build subset plan from unknown step: nope" in query_result["message"]
 
 
-class TestHardFailures(OutOfProcessExecutingGraphQLContextTestMatrix):
+class TestHardFailures(ExecutingGraphQLContextTestMatrix):
     def test_retry_hard_failure(self, graphql_context):
         selector = infer_pipeline_selector(graphql_context, "hard_failer")
         result = execute_dagster_graphql_and_finish_runs(
@@ -496,9 +476,9 @@ class TestHardFailures(OutOfProcessExecutingGraphQLContextTestMatrix):
             "pipelineRunLogs"
         ]["messages"]
 
-        assert step_started(logs, "hard_fail_or_0.compute")
-        assert step_did_not_run(logs, "hard_fail_or_0.compute")
-        assert step_did_not_run(logs, "increment.compute")
+        assert step_started(logs, "hard_fail_or_0")
+        assert step_did_not_run(logs, "hard_fail_or_0")
+        assert step_did_not_run(logs, "increment")
 
         retry = execute_dagster_graphql_and_finish_runs(
             graphql_context,
@@ -521,8 +501,8 @@ class TestHardFailures(OutOfProcessExecutingGraphQLContextTestMatrix):
         logs = get_all_logs_for_finished_run_via_subscription(graphql_context, run_id)[
             "pipelineRunLogs"
         ]["messages"]
-        assert step_did_succeed(logs, "hard_fail_or_0.compute")
-        assert step_did_succeed(logs, "increment.compute")
+        assert step_did_succeed(logs, "hard_fail_or_0")
+        assert step_did_succeed(logs, "increment")
 
 
 def _do_retry_intermediates_test(graphql_context, run_id, reexecution_run_id):
@@ -538,11 +518,11 @@ def _do_retry_intermediates_test(graphql_context, run_id, reexecution_run_id):
         },
     )
 
-    assert step_did_succeed(logs, "spawn.compute")
-    assert step_did_fail(logs, "fail.compute")
-    assert step_did_not_run(logs, "fail_2.compute")
-    assert step_did_not_run(logs, "fail_3.compute")
-    assert step_did_not_run(logs, "reset.compute")
+    assert step_did_succeed(logs, "spawn")
+    assert step_did_fail(logs, "fail")
+    assert step_did_not_run(logs, "fail_2")
+    assert step_did_not_run(logs, "fail_3")
+    assert step_did_not_run(logs, "reset")
 
     retry_one = execute_dagster_graphql_and_finish_runs(
         graphql_context,
@@ -564,29 +544,8 @@ def _do_retry_intermediates_test(graphql_context, run_id, reexecution_run_id):
     return retry_one
 
 
-class TestRetryExecutionSyncOnlyBehavior(
-    make_graphql_context_test_suite(
-        context_variants=[GraphQLContextVariant.in_memory_instance_in_process_env()]
-    )
-):
-    def test_retry_requires_intermediates_sync_only(self, graphql_context):
-        run_id = make_new_run_id()
-        reexecution_run_id = make_new_run_id()
-
-        retry_one = _do_retry_intermediates_test(graphql_context, run_id, reexecution_run_id)
-        assert not retry_one.errors
-        assert retry_one.data
-        assert retry_one.data["launchPipelineReexecution"]["__typename"] == "PythonError"
-        assert (
-            "Cannot perform reexecution with non persistent intermediates manager"
-            in retry_one.data["launchPipelineReexecution"]["message"]
-        )
-
-
 class TestRetryExecutionAsyncOnlyBehavior(
-    make_graphql_context_test_suite(
-        context_variants=GraphQLContextVariant.all_out_of_process_executing_variants()
-    )
+    make_graphql_context_test_suite(context_variants=GraphQLContextVariant.all_executing_variants())
 ):
     def test_retry_requires_intermediates_async_only(self, graphql_context):
         run_id = make_new_run_id()
@@ -615,7 +574,6 @@ class TestRetryExecutionAsyncOnlyBehavior(
                             "get_input_one": {"config": {"wait_to_terminate": True}},
                             "get_input_two": {"config": {"wait_to_terminate": True}},
                         },
-                        "storage": {"filesystem": {}},
                     },
                     "executionMetadata": {"runId": run_id},
                 }
@@ -631,16 +589,20 @@ class TestRetryExecutionAsyncOnlyBehavior(
 
         # The first step should succeed, the second should fail or not start,
         # and the following steps should not appear in records
-        assert step_did_succeed_in_records(records, "return_one.compute")
-        assert not step_did_fail_in_records(records, "return_one.compute")
+        assert step_did_succeed_in_records(records, "return_one")
+        assert not step_did_fail_in_records(records, "return_one")
         assert any(
             [
-                step_did_fail_in_records(records, "get_input_one.compute"),
-                step_did_not_run_in_records(records, "get_input_one.compute"),
+                step_did_fail_in_records(records, "get_input_one"),
+                step_did_not_run_in_records(records, "get_input_one"),
             ]
         )
-        assert step_did_not_run_in_records(records, "get_input_two.compute")
-        assert step_did_not_run_in_records(records, "sum_inputs.compute")
+        assert step_did_not_run_in_records(records, "get_input_two")
+        assert step_did_not_run_in_records(records, "sum_inputs")
+
+        # Wait for the original run to finish
+        poll_for_finished_run(instance, run_id, timeout=30)
+        assert instance.get_run_by_id(run_id).status == PipelineRunStatus.CANCELED
 
         # Start retry
         new_run_id = make_new_run_id()
@@ -657,7 +619,6 @@ class TestRetryExecutionAsyncOnlyBehavior(
                             "get_input_one": {"config": {"wait_to_terminate": False}},
                             "get_input_two": {"config": {"wait_to_terminate": False}},
                         },
-                        "storage": {"filesystem": {}},
                     },
                     "executionMetadata": {
                         "runId": new_run_id,
@@ -671,7 +632,7 @@ class TestRetryExecutionAsyncOnlyBehavior(
 
         retry_records = instance.all_logs(new_run_id)
         # The first step should not run and the other three steps should succeed in retry
-        assert step_did_not_run_in_records(retry_records, "return_one.compute")
-        assert step_did_succeed_in_records(retry_records, "get_input_one.compute")
-        assert step_did_succeed_in_records(retry_records, "get_input_two.compute")
-        assert step_did_succeed_in_records(retry_records, "sum_inputs.compute")
+        assert step_did_not_run_in_records(retry_records, "return_one")
+        assert step_did_succeed_in_records(retry_records, "get_input_one")
+        assert step_did_succeed_in_records(retry_records, "get_input_two")
+        assert step_did_succeed_in_records(retry_records, "sum_inputs")
